@@ -36,6 +36,7 @@ class ReferenceSequenceAnnotationAdapter(ObjectAdapterBase):
         self.__ecP = self.__rsaP.getEcProvider()
         self.__refD = self.__rsaP.getRefData()
         self.__matchD = self.__rsaP.getMatchInfo()
+        self.__ggP = self.__rsaP.getGlyGenProvider()
         #
 
     def filter(self, obj, **kwargs):
@@ -93,6 +94,7 @@ class ReferenceSequenceAnnotationAdapter(ObjectAdapterBase):
             #
             unpGeneDL = []
             unpAnnDL = []
+            glygenDL = []
             geneLookupD = {}
             geneFilterD = defaultdict(int)
             resourceFilterD = defaultdict(int)
@@ -167,6 +169,18 @@ class ReferenceSequenceAnnotationAdapter(ObjectAdapterBase):
 
                             else:
                                 unpAnnDL.append({"provenance_source": "UniProt", "annotation_id": tD["id_code"], "type": tD["resource"], "assignment_version": uD["version"]})
+                #
+                if self.__ggP and self.__ggP.hasGlycoprotein(unpId):
+                    logger.debug("Mapping glycoprotein for %r", unpId)
+                    glygenDL.append(
+                        {
+                            "provenance_source": "PDB",
+                            "annotation_id": unpId,
+                            "name": "Glycoprotein",
+                            "type": "GlyGen",
+                            "assignment_version": "1.0",
+                        }
+                    )
 
             #
             # raD {'resource_identifier': 'PF00503', 'provenance_source': 'SIFTS', 'resource_name': 'Pfam'}
@@ -177,17 +191,22 @@ class ReferenceSequenceAnnotationAdapter(ObjectAdapterBase):
             if peaDL:
                 qL = []
                 for peaD in peaDL:
-                    if peaD["provenance_source"] != "UniProt":
-                        qL.append(peaD)
+                    if (peaD["provenance_source"] == "UniProt") or (peaD["type"] == "GlyGen"):
+                        continue
+                    qL.append(peaD)
                 # Put back the base object list -
                 peaDL = qL
 
             for unpAnnD in unpAnnDL:
                 peaDL.append(unpAnnD)
             #
+            if glygenDL:
+                # logger.debug("%r glygenDL (%d) %r", entityKey, len(glygenDL), glygenDL)
+                peaDL.extend(glygenDL)
+
             if peaDL:
                 obj["rcsb_polymer_entity_annotation"] = peaDL
-                # logger.debug("annotation object is %r", obj["rcsb_polymer_entity_annotation"])
+                # logger.info("annotation object is %r", obj["rcsb_polymer_entity_annotation"])
             #
             # --------------  Add gene names -----------------
             #
